@@ -18,7 +18,14 @@ def job(func_or_queue, connection=None, *args, **kwargs):
         func = None
         queue = func_or_queue
 
-    if isinstance(queue, basestring):
+    try:
+        from django.utils import six
+        string_type = six.string_types
+    except ImportError:
+        # for django lt v1.5 and python 2
+        string_type = basestring
+
+    if isinstance(queue, string_type):
         try:
             queue = get_queue(queue)
             if connection is None:
